# Information Theory

> Information is neither created nor destroyed

-- Charles Seife, _Decoding the Universe_

Its been a long time since quantum physics was first accurately described by Maxwell, Bohr, Einstein, etc, but scientists and philosophers are just now begninning to realize that information may be driving it all. Maxwell's cat may not live or die when  human "sees" or measures the photon or the decohered state of the qubit. Nature "sees" and maintains a ledger of all information and will have "decided" the fate of the cat the instant the entangle photon(s) strike their detectors.

When a qubit decoheres it increases the entropy of a system by `k * log(2, 2)`, where k = Boltzmann's constant, assuming that it is a 50% (even odds) qubit. Just like Shannon entropy, the probabilities matter.

Information entropy is more fundamental than thermodynamic entropy. Thermodynamic entropy can have nonconservative fluctuations over microsecond time scales. Information entropy resolves the equation billions of billions of times faster (10's of orders of magnitude faster). Thermodynamics is just rolling dice and random collisions of particles. Information entropy is governed by laws and forces and energy present in a vacuum, with no measureable matter at all, no dice to roll. And yet information fluctuates in and out of existence perpetually in a vacuum.

# Awe

> Awe very properly hangs about it, since it is the immovable standard and silent witness of all our memories and assertions; and the past and the future, which in our anxious life are so differently interesting and so differently dark, are one seamless garment for the truth, shining like the sun.

-- George Santayana, _Skepticism and Animal Faith_